@@ -1,7 +1,5 @@
 package Exception::Multistate::BadAction;
-$Exception::Multistate::BadAction::VERSION = '0.009';
-use qbit;
-
+$Exception::Multistate::BadAction::VERSION = '0.010';
 use base qw(Exception::Multistate);
 
-TRUE;
+1;
