@@ -1,7 +1,5 @@
 package Exception::Multistate::NotFound;
-$Exception::Multistate::NotFound::VERSION = '0.009';
-use qbit;
-
+$Exception::Multistate::NotFound::VERSION = '0.010';
 use base qw(Exception::Multistate);
 
-TRUE;
+1;
